<?php

namespace Smsto\Hubspot\Http\Controllers\Api;

use Illuminate\Support\Facades\Http;
use Smsto\Hubspot\Http\Requests\Api\IndexCardsRequest;
use Smsto\Hubspot\Models\Settings;
use Illuminate\Support\Str;

class CardsController extends AdminController
{

    /**
     * Show the form for editing the specified resource.
     *
     * @param  \Smsto\Hubspot\Http\Requests\Api\IndexCardsRequest  $request
     * @return \Illuminate\Http\Response
     */
    public function index(IndexCardsRequest $request)
    {
        $validated = $request->validated();
        $settings = Settings::where([
            'hub_id' => $request->portalId,
        ])->firstOrFail();

        $response = Http::withToken($settings->api_key)->asJson()->acceptJson()->get('https://api.sms.to/v2/messages?&to=' . $validated['phone']);
        $response = json_decode($response, true);

        $result = [];
        if (!empty($response) && $response['success']) {
            foreach ($response['data'] as $key => $value) {
                $result[] = [
                    "objectId" => $key,
                    "title" => Str::limit($value['message'], 30, '...'),
                    'link' => null,
                    'status' => $value['status'],
                    'phone' => $value['to'],
                    'sender_id' => $value['sender_id'],
                    'message' => $value['message'],
                    'sent_at' => $value['sent_at']
                ];
            }
        }

        $result = [
            'results' => $result,
            'settingsAction' => [
                'type' => 'IFRAME',
                'windth' => 890,
                'height' => 748,
                'uri' => route('hubspot.web.settings.edit', ['settings' => $settings]),
                'label' => 'Settings'
            ],
            'primaryAction' => [
                'type' => 'IFRAME',
                'windth' => 890,
                'height' => 748,
                'uri' => route('hubspot.web.cards.gui', [
                    'settings' => $settings,
                    'to' => isset($validated['phone']) ? $validated['phone'] : "",
                    'sender_id' => $settings->sender_id,
                    'active_tab' => 'single',
                    'callback_url' => route('hubspot.api.smsto.callback', ['settings' => $settings, 'associatedObjectId' => $validated['associatedObjectId']]),
                ]),
                'label' => 'Send SMS'
            ],
            "secondaryActions" => [
                0 => [
                    "type" => "IFRAME",
                    "width" => 890,
                    "height" => 748,
                    'uri' => route('hubspot.web.cards.gui', [
                        'settings' => $settings,
                        'to' => isset($validated['phone']) ? $validated['phone'] : "",
                        'sender_id' => $settings->sender_id,
                        'active_tab' => 'single',
                        'route_name' => 'reports',
                    ]),
                    "label" => "View all"
                ]
            ]
        ];

        return response($result);
    }
}
